# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateWarehouseResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        warehouse_instance_id: str = None,
    ):
        self.request_id = request_id
        self.warehouse_instance_id = warehouse_instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.warehouse_instance_id is not None:
            result['WarehouseInstanceId'] = self.warehouse_instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('WarehouseInstanceId') is not None:
            self.warehouse_instance_id = m.get('WarehouseInstanceId')

        return self

